==> activity-center-api-0.9.55-xhw-20190822.082725-6-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/reward/config/RewardedActivityPrizeConfig.java <==
package cn.com.duiba.tuia.activity.center.api.dto.reward.config;

import java.io.Serializable;
import java.util.Map;

/**
 * 激励互动奖励配置
 *
 * @author zhangbaiqiang
 * @date 2019-07-14
 */
public class RewardedActivityPrizeConfig implements Serializable {
    private static final long serialVersionUID = -7008896281301077095L;

    /**
     * 时间戳
     */
    private Long timestamp;

    /**
     * 默认奖品id
     */
    private Integer defaultPrizeId;

    /**
     * 默认奖品名称
     */
    private String defaultPrizeTitle;

    /**
     * 奖励最少参与次数
     */
    private Integer minRewardedTimes;

    /**
     * 奖励明细
     */
    private Map<Integer, RewardedActivityPrizeDetail> prize;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Integer getDefaultPrizeId() {
        return defaultPrizeId;
    }

    public void setDefaultPrizeId(Integer defaultPrizeId) {
        this.defaultPrizeId = defaultPrizeId;
    }

    public String getDefaultPrizeTitle() {
        return defaultPrizeTitle;
    }

    public void setDefaultPrizeTitle(String defaultPrizeTitle) {
        this.defaultPrizeTitle = defaultPrizeTitle;
    }

    public Integer getMinRewardedTimes() {
        return minRewardedTimes;
    }

    public void setMinRewardedTimes(Integer minRewardedTimes) {
        this.minRewardedTimes = minRewardedTimes;
    }

    public Map<Integer, RewardedActivityPrizeDetail> getPrize() {
        return prize;
    }

    public void setPrize(Map<Integer, RewardedActivityPrizeDetail> prize) {
        this.prize = prize;
    }
}

==> activity-center-api-0.9.79-xhw1-20190930.081321-3-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/reward/config/RewardedActivityPrizeConfig.java <==
package cn.com.duiba.tuia.activity.center.api.dto.reward.config;

import java.io.Serializable;
import java.util.Map;

/**
 * 激励互动奖励配置
 *
 * @author zhangbaiqiang
 * @date 2019-07-14
 */
public class RewardedActivityPrizeConfig implements Serializable {
    private static final long serialVersionUID = -7008896281301077095L;

    /**
     * 时间戳
     */
    private Long timestamp;

    /**
     * 默认奖品id
     */
    private Long defaultPrizeId;

    /**
     * 默认奖品名称
     */
    private String defaultPrizeTitle;

    /**
     * 奖励最少参与次数
     */
    private Integer minRewardedTimes;

    /**
     * 奖励明细
     */
    private Map<Integer, RewardedActivityPrizeDetail> prize;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Long getDefaultPrizeId() {
        return defaultPrizeId;
    }

    public void setDefaultPrizeId(Long defaultPrizeId) {
        this.defaultPrizeId = defaultPrizeId;
    }

    public String getDefaultPrizeTitle() {
        return defaultPrizeTitle;
    }

    public void setDefaultPrizeTitle(String defaultPrizeTitle) {
        this.defaultPrizeTitle = defaultPrizeTitle;
    }

    public Integer getMinRewardedTimes() {
        return minRewardedTimes;
    }

    public void setMinRewardedTimes(Integer minRewardedTimes) {
        this.minRewardedTimes = minRewardedTimes;
    }

    public Map<Integer, RewardedActivityPrizeDetail> getPrize() {
        return prize;
    }

    public void setPrize(Map<Integer, RewardedActivityPrizeDetail> prize) {
        this.prize = prize;
    }
}
